@@ -1,5 +1,5 @@
 /*
- *  nautilus-column-provider.c - Interface for Nautilus extensions 
+ *  nautilus-column-provider.c - Interface for Nautilus extensions
  *                               that provide column specifications.
  *
  *  Copyright (C) 2003 Novell, Inc.
@@ -16,7 +16,7 @@
  *
  *  You should have received a copy of the GNU Library General Public
  *  License along with this library; if not, see <http://www.gnu.org/licenses/>.
- * 
+ *
  *  Author:  Dave Camp <dave@ximian.com>
  *
  */
@@ -41,31 +41,33 @@ nautilus_column_provider_base_init (gpointer g_class)
 {
 }
 
-GType                   
+GType
 nautilus_column_provider_get_type (void)
 {
-	static GType type = 0;
+    static GType type = 0;
 
-	if (!type) {
-		const GTypeInfo info = {
-			sizeof (NautilusColumnProviderIface),
-			nautilus_column_provider_base_init,
-			NULL,
-			NULL,
-			NULL,
-			NULL,
-			0,
-			0,
-			NULL
-		};
-		
-		type = g_type_register_static (G_TYPE_INTERFACE, 
-					       "NautilusColumnProvider",
-					       &info, 0);
-		g_type_interface_add_prerequisite (type, G_TYPE_OBJECT);
-	}
+    if (!type)
+    {
+        const GTypeInfo info =
+        {
+            sizeof (NautilusColumnProviderIface),
+            nautilus_column_provider_base_init,
+            NULL,
+            NULL,
+            NULL,
+            NULL,
+            0,
+            0,
+            NULL
+        };
 
-	return type;
+        type = g_type_register_static (G_TYPE_INTERFACE,
+                                       "NautilusColumnProvider",
+                                       &info, 0);
+        g_type_interface_add_prerequisite (type, G_TYPE_OBJECT);
+    }
+
+    return type;
 }
 
 /**
@@ -77,11 +79,9 @@ nautilus_column_provider_get_type (void)
 GList *
 nautilus_column_provider_get_columns (NautilusColumnProvider *provider)
 {
-	g_return_val_if_fail (NAUTILUS_IS_COLUMN_PROVIDER (provider), NULL);
-	g_return_val_if_fail (NAUTILUS_COLUMN_PROVIDER_GET_IFACE (provider)->get_columns != NULL, NULL);
+    g_return_val_if_fail (NAUTILUS_IS_COLUMN_PROVIDER (provider), NULL);
+    g_return_val_if_fail (NAUTILUS_COLUMN_PROVIDER_GET_IFACE (provider)->get_columns != NULL, NULL);
 
-	return NAUTILUS_COLUMN_PROVIDER_GET_IFACE (provider)->get_columns 
-		(provider);
+    return NAUTILUS_COLUMN_PROVIDER_GET_IFACE (provider)->get_columns
+               (provider);
 }
-
-					       
