@@ -13,6 +13,10 @@
 #include <string.h>
 #include <unistd.h>
 
+#ifdef HAVE_EXEMPI
+#include <exempi/xmp.h>
+#endif
+
 int
 main (int   argc,
       char *argv[])
@@ -27,6 +31,10 @@ main (int   argc,
 
     g_set_prgname ("nautilus-desktop");
 
+#ifdef HAVE_EXEMPI
+    xmp_init ();
+#endif
+
     gdk_set_allowed_backends ("x11");
 
     nautilus_register_resource ();
