@@ -45,6 +45,8 @@ gboolean nautilus_is_home_directory_file             (GFile *dir,
 						      const char *filename);
 gboolean nautilus_is_in_system_dir                   (GFile *location);
 gboolean nautilus_is_search_directory                (GFile *dir);
+gboolean nautilus_is_recent_directory                (GFile *dir);
+gboolean nautilus_is_trash_directory                 (GFile *dir);
 gboolean nautilus_is_other_locations_directory       (GFile *dir);
 GMount * nautilus_get_mounted_mount_for_root         (GFile *location);
 
@@ -123,4 +125,6 @@ gboolean nautilus_file_can_rename_files (GList *files);
 
 GList * nautilus_file_list_from_uri_list (GList *uris);
 
+gchar * nautilus_uri_to_native_uri (const gchar *uri);
+
 #endif /* NAUTILUS_FILE_UTILITIES_H */
