@@ -65,6 +65,6 @@ struct NautilusListViewDetails {
 
   GQuark last_sort_attr;
 
-  GIcon *icon;
+  GRegex *regex;
 };
 
