@@ -92,6 +92,7 @@ typedef struct
     GQueue *unhandled_uris;
 } ApplicationLaunchParameters;
 
+/* Microsoft mime types at https://blogs.msdn.microsoft.com/vsofficedeveloper/2008/05/08/office-2007-file-format-mime-types-for-http-content-streaming-2/ */
 struct
 {
     char *name;
@@ -128,6 +129,7 @@ struct
         "application/x-kword",
         "application/x-kword-crypt",
         "application/x-lyx",
+        "application/vnd.openxmlformats-officedocument.wordprocessingml.document",
         NULL}},
     { N_("Illustration"),
       { "application/illustrator",
@@ -159,6 +161,7 @@ struct
         "application/postscript",
         "application/x-dvi",
         "image/x-eps",
+        "image/vnd.djvu+multipage",
         NULL}},
     { N_("Picture"),
       { "application/vnd.oasis.opendocument.image",
@@ -184,6 +187,7 @@ struct
         "application/vnd.oasis.opendocument.presentation",
         "application/x-magicpoint",
         "application/x-kpresenter",
+        "application/vnd.openxmlformats-officedocument.presentationml.presentation",
         NULL}},
     { N_("Spreadsheet"),
       { "application/vnd.lotus-1-2-3",
@@ -198,6 +202,7 @@ struct
         "application/x-quattropro",
         "application/x-sc",
         "application/x-siag",
+        "application/vnd.openxmlformats-officedocument.spreadsheetml.sheet",
         NULL}},
     { N_("Text File"),
       { "text/plain",
@@ -710,13 +715,16 @@ get_activation_action (NautilusFile *file)
 {
     ActivationAction action;
     char *activation_uri;
-    gboolean handles_extract;
+    gboolean handles_extract = FALSE;
     g_autoptr (GAppInfo) app_info = NULL;
     const gchar* app_id;
 
     app_info = nautilus_mime_get_default_application_for_file (file);
-    app_id = g_app_info_get_id (app_info);
-    handles_extract = g_strcmp0 (app_id, NAUTILUS_DESKTOP_ID) == 0;
+    if (app_info != NULL)
+    {
+        app_id = g_app_info_get_id (app_info);
+        handles_extract = g_strcmp0 (app_id, NAUTILUS_DESKTOP_ID) == 0;
+    }
     if (handles_extract && nautilus_file_is_archive (file))
     {
         return ACTIVATION_ACTION_EXTRACT;
