@@ -28,39 +28,12 @@
 #include <glib.h>
 #include <gtk/gtk.h>
 
-typedef struct _NautilusNotebookClass	NautilusNotebookClass;
-typedef struct _NautilusNotebook	NautilusNotebook;
-typedef struct _NautilusNotebookPrivate	NautilusNotebookPrivate;
-
 #include "nautilus-window-slot.h"
 
 G_BEGIN_DECLS
 
 #define NAUTILUS_TYPE_NOTEBOOK		(nautilus_notebook_get_type ())
-#define NAUTILUS_NOTEBOOK(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), NAUTILUS_TYPE_NOTEBOOK, NautilusNotebook))
-#define NAUTILUS_NOTEBOOK_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), NAUTILUS_TYPE_NOTEBOOK, NautilusNotebookClass))
-#define NAUTILUS_IS_NOTEBOOK(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), NAUTILUS_TYPE_NOTEBOOK))
-#define NAUTILUS_IS_NOTEBOOK_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), NAUTILUS_TYPE_NOTEBOOK))
-#define NAUTILUS_NOTEBOOK_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), NAUTILUS_TYPE_NOTEBOOK, NautilusNotebookClass))
-
-struct _NautilusNotebook
-{
-	GtkNotebook parent;
-
-	/*< private >*/
-        NautilusNotebookPrivate *priv;
-};
-
-struct _NautilusNotebookClass
-{
-        GtkNotebookClass parent_class;
-
-	/* Signals */
-	void	 (* tab_close_request)  (NautilusNotebook *notebook,
-					 NautilusWindowSlot *slot);
-};
-
-GType		nautilus_notebook_get_type		(void);
+G_DECLARE_FINAL_TYPE (NautilusNotebook, nautilus_notebook, NAUTILUS, NOTEBOOK, GtkNotebook)
 
 int		nautilus_notebook_add_tab	(NautilusNotebook *nb,
 						 NautilusWindowSlot *slot,
