@@ -40,6 +40,7 @@ struct _NautilusRenameFilePopoverController
     GtkWidget *rename_file_popover;
 
     gint closed_handler_id;
+    gint file_changed_handler_id;
 };
 
 G_DEFINE_TYPE (NautilusRenameFilePopoverController, nautilus_rename_file_popover_controller, NAUTILUS_TYPE_FILE_NAME_WIDGET_CONTROLLER)
@@ -125,34 +126,16 @@ nautilus_rename_file_popover_controller_ignore_existing_file (NautilusFileNameWi
     return nautilus_file_compare_display_name (self->target_file, display_name) == 0;
 }
 
-/* Albeit a misnomer, this only handles presses of the F2 key.
- * This is to restore functionality, lost in the introduction of the popover,
- * where pressing F2 while renaming would select all text.
- * The bug reporter also requested switching between selecting the name
- * and the name with extension.
- *
- * See https://bugzilla.gnome.org/show_bug.cgi?id=774361
- */
 static gboolean
-name_entry_on_key_pressed (GtkWidget *widget,
-                           GdkEvent  *event,
-                           gpointer   user_data)
+name_entry_on_f2_pressed (GtkWidget                           *widget,
+                          NautilusRenameFilePopoverController *self)
 {
-    GdkEventKey *key_event;
-    NautilusRenameFilePopoverController *self;
     guint text_length;
     gint start_pos;
     gint end_pos;
     gboolean all_selected;
 
-    key_event = (GdkEventKey *)event;
-    if (key_event->keyval != GDK_KEY_F2)
-    {
-        return GDK_EVENT_PROPAGATE;
-    }
-
-    self = NAUTILUS_RENAME_FILE_POPOVER_CONTROLLER (user_data);
-    text_length = (guint)gtk_entry_get_text_length (GTK_ENTRY (widget));
+    text_length = (guint) gtk_entry_get_text_length (GTK_ENTRY (widget));
     if (text_length == 0)
     {
         return GDK_EVENT_PROPAGATE;
@@ -161,7 +144,7 @@ name_entry_on_key_pressed (GtkWidget *widget,
     gtk_editable_get_selection_bounds (GTK_EDITABLE (widget),
                                        &start_pos, &end_pos);
 
-    all_selected = (start_pos == 0) && ((guint)end_pos == text_length);
+    all_selected = (start_pos == 0) && ((guint) end_pos == text_length);
     if (!all_selected || !nautilus_file_is_regular_file (self->target_file))
     {
         gtk_editable_select_region (GTK_EDITABLE (widget), 0, -1);
@@ -181,6 +164,63 @@ name_entry_on_key_pressed (GtkWidget *widget,
     return GDK_EVENT_PROPAGATE;
 }
 
+static gboolean
+name_entry_on_undo (GtkWidget                           *widget,
+                    NautilusRenameFilePopoverController *self)
+{
+    g_autofree gchar *display_name = NULL;
+
+    display_name = nautilus_file_get_display_name (self->target_file);
+
+    gtk_entry_set_text (GTK_ENTRY (widget), display_name);
+
+    gtk_editable_select_region (GTK_EDITABLE (widget), 0, -1);
+
+    return GDK_EVENT_STOP;
+}
+
+static gboolean
+name_entry_on_key_pressed (GtkWidget *widget,
+                           GdkEvent  *event,
+                           gpointer   user_data)
+{
+    GdkEventKey *key_event;
+    NautilusRenameFilePopoverController *self;
+
+    key_event = (GdkEventKey *) event;
+    self = NAUTILUS_RENAME_FILE_POPOVER_CONTROLLER (user_data);
+
+    if (key_event->keyval == GDK_KEY_F2)
+    {
+        return name_entry_on_f2_pressed (widget, self);
+    }
+    else if (key_event->keyval == GDK_KEY_z &&
+             (key_event->state & GDK_CONTROL_MASK) != 0)
+    {
+        return name_entry_on_undo (widget, self);
+    }
+
+    return GDK_EVENT_PROPAGATE;
+}
+
+static void
+target_file_on_changed (NautilusFile *file,
+                        gpointer      user_data)
+{
+    NautilusRenameFilePopoverController *controller;
+
+    controller = NAUTILUS_RENAME_FILE_POPOVER_CONTROLLER (user_data);
+
+    if (nautilus_file_is_gone (file))
+    {
+        g_signal_handler_disconnect (controller->target_file,
+                                     controller->file_changed_handler_id);
+        controller->file_changed_handler_id = 0;
+
+        g_signal_emit_by_name (controller, "cancelled");
+    }
+}
+
 NautilusRenameFilePopoverController *
 nautilus_rename_file_popover_controller_new (NautilusFile *target_file,
                                              GdkRectangle *pointing_to,
@@ -236,6 +276,12 @@ nautilus_rename_file_popover_controller_new (NautilusFile *target_file,
                                                 "closed",
                                                 (GCallback) rename_file_popover_controller_on_closed,
                                                 self);
+
+    self->file_changed_handler_id = g_signal_connect (self->target_file,
+                                                      "changed",
+                                                      G_CALLBACK (target_file_on_changed),
+                                                      self);
+
     g_signal_connect (rename_file_popover,
                       "unmap",
                       (GCallback) gtk_widget_destroy,
@@ -314,6 +360,12 @@ nautilus_rename_file_popover_controller_finalize (GObject *object)
         self->rename_file_popover = NULL;
     }
 
+    if (self->file_changed_handler_id != 0)
+    {
+        g_signal_handler_disconnect (self->target_file,
+                                     self->file_changed_handler_id);
+        self->file_changed_handler_id = 0;
+    }
     nautilus_file_unref (self->target_file);
 
     G_OBJECT_CLASS (nautilus_rename_file_popover_controller_parent_class)->finalize (object);
