@@ -219,7 +219,6 @@ visit_directory (GFile            *dir,
     gboolean visited;
     guint64 atime;
     guint64 mtime;
-    GPtrArray *date_range;
     GDateTime *initial_date;
     GDateTime *end_date;
 
@@ -241,6 +240,8 @@ visit_directory (GFile            *dir,
 
     while ((info = g_file_enumerator_next_file (enumerator, data->cancellable, NULL)) != NULL)
     {
+        g_autoptr (GPtrArray) date_range = NULL;
+
         display_name = g_file_info_get_display_name (info);
         if (display_name == NULL)
         {
@@ -296,7 +297,6 @@ visit_directory (GFile            *dir,
             found = nautilus_file_date_in_between (current_file_time,
                                                    initial_date,
                                                    end_date);
-            g_ptr_array_unref (date_range);
         }
 
         if (found)
