@@ -390,6 +390,43 @@ real_select_all (NautilusFilesView *files_view)
 static void
 real_reveal_selection (NautilusFilesView *files_view)
 {
+    GList *selection;
+    NautilusViewItemModel *item_model;
+    NautilusViewIconController *self = NAUTILUS_VIEW_ICON_CONTROLLER (files_view);
+    GtkWidget *item_ui;
+    GtkAllocation allocation;
+    GtkWidget *content_widget;
+    GtkAdjustment *vadjustment;
+    int view_height;
+
+    selection = nautilus_view_get_selection (NAUTILUS_VIEW (files_view));
+    if (selection == NULL)
+    {
+        return;
+    }
+
+    item_model = nautilus_view_model_get_item_from_file (self->model,
+                                                         NAUTILUS_FILE (selection->data));
+    item_ui = nautilus_view_item_model_get_item_ui (item_model);
+    gtk_widget_get_allocation (item_ui, &allocation);
+    content_widget = nautilus_files_view_get_content_widget (files_view);
+    view_height = gtk_widget_get_allocated_height (content_widget);
+    vadjustment = gtk_scrolled_window_get_vadjustment (GTK_SCROLLED_WINDOW (content_widget));
+
+    /* Scroll only as necessary. TODO: Would be nice to have this as part of
+     * GtkFlowBox. GtkTreeView has something similar. */
+    if (allocation.y < gtk_adjustment_get_value (vadjustment))
+    {
+        gtk_adjustment_set_value (vadjustment, allocation.y);
+    }
+    else if (allocation.y + allocation.height >
+             gtk_adjustment_get_value (vadjustment) + view_height)
+    {
+        gtk_adjustment_set_value (vadjustment,
+                                  allocation.y + allocation.height - view_height);
+    }
+
+    g_list_foreach (selection, (GFunc) g_object_unref, NULL);
 }
 
 static gboolean
@@ -546,6 +583,18 @@ real_get_zoom_level_percentage (NautilusFilesView *files_view)
            NAUTILUS_CANVAS_ICON_SIZE_LARGE;
 }
 
+static gboolean
+real_is_zoom_level_default (NautilusFilesView *files_view)
+{
+    NautilusViewIconController *self;
+    guint icon_size;
+
+    self = NAUTILUS_VIEW_ICON_CONTROLLER (files_view);
+    icon_size = get_icon_size_for_zoom_level (self->zoom_level);
+
+    return icon_size == NAUTILUS_CANVAS_ICON_SIZE_LARGE;
+}
+
 static gboolean
 real_can_zoom_in (NautilusFilesView *files_view)
 {
@@ -622,7 +671,7 @@ on_button_press_event (GtkWidget *widget,
         if (g_list_find (selection, selected_file) == NULL)
         {
             g_list_foreach (selection, (GFunc) g_object_unref, NULL);
-            selection = g_list_append (NULL, selected_file);
+            selection = g_list_append (NULL, g_object_ref (selected_file));
         }
         else
         {
@@ -742,8 +791,7 @@ action_sort_order_changed (GSimpleAction *action,
 
 static void
 real_add_files (NautilusFilesView *files_view,
-                GList             *files,
-                NautilusDirectory *directory)
+                GList             *files)
 {
     NautilusViewIconController *self = NAUTILUS_VIEW_ICON_CONTROLLER (files_view);
     g_autoptr (GQueue) files_queue;
@@ -887,6 +935,7 @@ nautilus_view_icon_controller_class_init (NautilusViewIconControllerClass *klass
     files_view_class->select_first = real_select_first;
     files_view_class->restore_standard_zoom_level = real_restore_standard_zoom_level;
     files_view_class->get_zoom_level_percentage = real_get_zoom_level_percentage;
+    files_view_class->is_zoom_level_default = real_is_zoom_level_default;
     files_view_class->compute_rename_popover_pointing_to = real_compute_rename_popover_pointing_to;
 }
 
